@@ -1,25 +1,28 @@
 import os
-import sys
-import pickle
+import json
 import asyncio
 import uvicorn
 from .model import Model
+from .logger import Logger
 from threading import Thread
+from .payload import Payload
 from conf import Configuration  # type: ignore
 from .messenger import Messenger
-from .utils import funcs, analyse, Payload
 from fastapi.staticfiles import StaticFiles
 from fastapi import FastAPI, Request, Response
+from .tools import funcs, analyse, before_run, send_next, verif_event
 
-_req = None
-loop = None
+_req = Model(init=False)
+loop = asyncio.get_event_loop()
 
 webserver = FastAPI(title="Ampalibe server")
-if os.path.isdir("assets/public"):
-    webserver.mount("/asset", StaticFiles(directory="assets/public"), name="asset")
+if not os.path.isdir("assets/public"):
+    os.makedirs("assets/public", exist_ok=True)
+
+webserver.mount("/asset", StaticFiles(directory="assets/public"), name="asset")
 
 
-class Extra:
+class Init:
     def __init__(self, *args):
         self.query = Model()
         self.chat = Messenger()
@@ -32,8 +35,6 @@ class Extra:
         global _req
         _req = Model()
 
-        global loop
-        loop = asyncio.get_event_loop()
         Thread(target=loop.run_forever).start()
 
         uvicorn.run(
@@ -43,7 +44,7 @@ class Extra:
         )
 
 
-class Server:
+class Server(Request):
     """
     Content of webhook
     """
@@ -60,9 +61,8 @@ class Server:
         """
         Main verification for bot server is received here
         """
-        fb_token = request.query_params.get("hub.verify_token")
 
-        if fb_token == Configuration.VERIF_TOKEN:
+        if request.query_params.get("hub.verify_token") == Configuration.VERIF_TOKEN:
             return Response(content=request.query_params["hub.challenge"])
         return "Failed to verify token"
 
@@ -72,79 +72,70 @@ class Server:
         Main Requests for bot messenger is received here.
         """
         testmode = request.query_params.get("testmode")
-        data = await request.json()
+        try:
+            data = await request.json()
+        except json.decoder.JSONDecodeError:
+            return "..."
 
         # data analysis and decomposition
         sender_id, payload, message = analyse(data)
 
-        if payload.webhook not in ("message", "postback"):
-            if funcs["event"].get(payload.webhook):
-                kw = {"sender_id": sender_id, "watermark": payload, "message": message}
-                if testmode:
-                    funcs["event"][payload.webhook](**kw)
-                else:
-                    Thread(target=funcs["event"][payload.webhook], kwargs=kw).start()
+        if payload.webhook in ("read", "delivery", "reaction"):
+            verif_event(sender_id, payload, message, testmode)
             return {"status": "ok"}
 
         _req._verif_user(sender_id)
-        # get action for the current user
-        action = _req.get_action(sender_id)
-        lang = _req.get_lang(sender_id)
+        action, lang = _req.get(sender_id, "action", "lang")
 
         if payload in ("/__next", "/__more"):
-            bot = Messenger()
-            if os.path.isfile(f"assets/private/.__{sender_id}"):
-                elements = pickle.load(open(f"assets/private/.__{sender_id}", "rb"))
-                if payload == "/__next":
-                    bot.send_template(sender_id, elements[0], next=elements[1])
-                else:
-                    bot.send_quick_reply(
-                        sender_id, elements[0], elements[1], next=elements[2]
-                    )
-                return {"status": "ok"}
+            send_next(sender_id, payload)
+            return {"status": "ok"}
 
         if os.path.isfile(f"assets/private/.__{sender_id}"):
             os.remove(f"assets/private/.__{sender_id}")
 
         payload, kw = Payload.trt_payload_in(payload)
-        if action:
-            action, kw_tmp = Payload.trt_payload_in(action)
-            kw.update(kw_tmp)
+        kw.update(
+            {
+                "sender_id": sender_id,
+                "cmd": payload,
+                "message": message,
+                "lang": lang,
+            }
+        )
+
         command = funcs["command"].get(payload.split()[0])
-        kw["sender_id"] = sender_id
-        kw["cmd"] = payload
-        kw["message"] = message
-        kw["lang"] = lang
+
         if command:
             _req.set_action(sender_id, None)
             if testmode:
-                return command(**kw)
+                return before_run(command, **kw)
             else:
                 Thread(
-                    target=command,
+                    target=before_run,
+                    args=(command,),
                     kwargs=kw,
                 ).start()
-        elif action and funcs["action"].get(action):
-            """
-            CASE an action is set.
-            """
-            if testmode:
-                return funcs["action"].get(action)(**kw)
-            Thread(target=funcs["action"].get(action), kwargs=kw).start()
+        elif action:
+            action, kw_tmp = Payload.trt_payload_in(action)
+            kw.update(kw_tmp)
+
+            if funcs["action"].get(action):
+                if testmode:
+                    return before_run(funcs["action"].get(action), **kw)
+                Thread(
+                    target=before_run,
+                    args=(funcs["action"].get(action),),
+                    kwargs=kw,
+                ).start()
+            else:
+                Logger.error(f'⚠ Error! action "{action}" undeclared ')
         else:
             command = funcs["command"].get("/")
-            if action:
-                print(
-                    f'\033[48:5:166m⚠ Warning!\033[0m action "{action}" undeclared',
-                    file=sys.stderr,
-                )
             if command:
                 if testmode:
-                    return command(**kw)
-                Thread(target=command, kwargs=kw).start()
+                    return before_run(command, **kw)
+                Thread(target=before_run, args=(command,), kwargs=kw).start()
             else:
-                print(
-                    "\033[31mError! \033[0mDefault route '/' function undeclared.",
-                    file=sys.stderr,
-                )
+                Logger.error("⚠ Error! Default route '/' function undeclared.")
         return {"status": "ok"}
