@@ -1,4 +1,4 @@
-env = """# PAGE ACCESS TOKEN 
+ENV = """# PAGE ACCESS TOKEN 
 export AMP_ACCESS_TOKEN=
 
 # PAGE VERIF TOKEN
@@ -9,17 +9,15 @@ export AMP_VERIF_TOKEN=
 export ADAPTER=SQLITE
 #export ADAPTER=MYSQL
 #export ADAPTER=POSTGRESQL
+#export ADAPTER=MONGODB
 
-####### CASE MYSQL OR POSTGRESQL ADAPTER
+####### CASE MYSQL, POSTGRESQL OR MONGODB ADAPTER
 export DB_HOST=
 export DB_USER=
 export DB_PASSWORD=
 export DB_NAME=
-
-# CASE MYSQL ADAPTER
-# export DB_PORT=3306
-# CASE POSTGRESQL ADAPTER
-# export DB_PORT=5432
+#export DB_PORT=
+#export SRV_PROTOCOL=1
 
 ####### CASE SQLITE ADAPTER
 export DB_FILE=ampalibe.db
@@ -34,7 +32,7 @@ export AMP_URL=
 
 """
 
-env_cmd = """:: PAGE ACCESS TOKEN 
+ENV_CMD = """:: PAGE ACCESS TOKEN 
 set AMP_ACCESS_TOKEN=
 
 :: PAGE VERIF TOKEN
@@ -44,16 +42,15 @@ set AMP_VERIF_TOKEN=
 set ADAPTER=SQLITE
 :: set ADAPTER=MYSQL
 :: set ADAPTER=POSTGRESQL
+:: set ADAPTER=MONGODB
 
-::::: CASE MYSQL ADAPTER OR POSTGRESQL ADAPTER
+::::: CASE MYSQL, POSTGRESQL OR MONGODB ADAPTER
 set DB_HOST=
 set DB_USER=
 set DB_PASSWORD=
 set DB_NAME=
-:: CASE MYSQL ADAPTER
-set DB_PORT=3306
-:: CASE POSTGRESQL ADAPTER
-:: set DB_PORT=5432
+:: set DB_PORT=
+:: set SRV_PROTOCOL=1
 
 :: CASE SQLITE ADAPTER
 set DB_FILE=ampalibe.db
@@ -67,7 +64,8 @@ set AMP_PORT=4555
 set AMP_URL=
 
 """
-core = """import ampalibe
+
+CORE = """import ampalibe
 from ampalibe import Messenger
 
 chat = Messenger()
@@ -76,7 +74,7 @@ chat = Messenger()
 # chat.get_started()
 
 @ampalibe.command('/')
-def main(sender_id, cmd, **extends):
+def main(sender_id, cmd, **ext):
     '''
     main function where messages received on
     the facebook page come in.
@@ -85,17 +83,16 @@ def main(sender_id, cmd, **extends):
         sender facebook id
     @param cmd String: 
         message content
-    @param extends Dict: 
+    @param ext Dict: 
         contain list of others
             data sent by facebook (sending time, ...)
             data sent by your payload if not set in parameter
     '''
     
-    chat.send_message(sender_id, "Hello, Ampalibe")
+    chat.send_text(sender_id, "Hello, Ampalibe")
     """
 
-
-conf = """from os import environ as env
+CONF = """from os import environ as env
 
 
 class Configuration:
@@ -110,8 +107,9 @@ class Configuration:
     DB_HOST = env.get('DB_HOST', 'localhost')
     DB_USER = env.get('DB_USER', 'root')
     DB_PASSWORD = env.get('DB_PASSWORD', '')
-    DB_PORT = env.get('DB_PORT', 3306)
+    DB_PORT = env.get('DB_PORT')
     DB_NAME = env.get('DB_NAME')
+    SRV_PROTOCOL = env.get('SRV_PROTOCOL')
 
     ACCESS_TOKEN = env.get('AMP_ACCESS_TOKEN')
     VERIF_TOKEN = env.get('AMP_VERIF_TOKEN')
@@ -119,9 +117,10 @@ class Configuration:
     APP_HOST = env.get('AMP_HOST', '0.0.0.0')
     APP_PORT = int(env.get('AMP_PORT', 4555))
     APP_URL = env.get('AMP_URL')
+    
 """
 
-langs = """{
+LANGS = """{
     "hello_world": {
         "en": "Hello World",
         "fr": "Bonjour le monde"
